WordCloud for Python documentation
==================================

Here you find instructions on how to create wordclouds with my Python wordcloud project. 
Compared to other wordclouds, my algorithm has the advantage of

* filling all available space.
* being able to use arbitrary masks.
* having a stupid simple algorithm (with an efficient implementation) that can be easily modified.
* being in Python

Check out the :ref:`example_gallery`.

The code of the project is on Github: `word_cloud <https://github.com/amueller/word_cloud>`_

  .. figure:: images/a_new_hope.png
     :width: 300px
     :target: auto_examples/a_new_hope.html
     :align: center

.. toctree::
    :hidden:
    :caption: User Documentation
    
    references
    cli
    auto_examples/index
    changelog

.. toctree::
    :hidden:
    :caption: Contributor Documentation

    make_a_release
